summaryrefslogtreecommitdiffstats
path: root/kregexpeditor/KWidgetStreamer
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
commit955e20356d63ed405198c8143617a8a0ca8bfc02 (patch)
tree9a9ab22c86d212a5655014ad752e96b04c0c86a9 /kregexpeditor/KWidgetStreamer
parentbf280726d5d22f33d33e4f9e771220c725249407 (diff)
downloadtdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.tar.gz
tdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bf280726d5d22f33d33e4f9e771220c725249407.
Diffstat (limited to 'kregexpeditor/KWidgetStreamer')
-rw-r--r--kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp86
1 files changed, 43 insertions, 43 deletions
diff --git a/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp b/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp
index 9015aaa..42d411b 100644
--- a/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp
+++ b/kregexpeditor/KWidgetStreamer/kwidgetstreamer.cpp
@@ -48,11 +48,11 @@ void KWidgetStreamer::propertyToStream( const TQObject* from, TQDataStream& stre
if ( ! from->inherits(TQWIDGET_OBJECT_NAME_STRING) )
return;
- // Serializing all the children (if any).
- const TQObjectList children = from->childrenListObject();
- if ( !children.isEmpty() ) {
- stream << children.count();
- for ( TQObjectListIt it = TQObjectListIt(children); *it; ++it ) {
+ // Serializing all the tqchildren (if any).
+ const TQObjectList tqchildren = from->childrenListObject();
+ if ( !tqchildren.isEmpty() ) {
+ stream << tqchildren.count();
+ for ( TQObjectListIt it = TQObjectListIt(tqchildren); *it; ++it ) {
toStream( *it, stream );
}
}
@@ -83,14 +83,14 @@ void KWidgetStreamer::propertyFromStream( TQDataStream& stream, TQObject* to )
if ( ! to->inherits(TQWIDGET_OBJECT_NAME_STRING) )
return;
- // Stream in all the children (if any)
- const TQObjectList children = to->childrenListObject();
+ // Stream in all the tqchildren (if any)
+ const TQObjectList tqchildren = to->childrenListObject();
unsigned int count;
stream >> count;
- if ( !children.isEmpty() ) {
- Q_ASSERT( count == children.count() );
- for ( TQObjectListIt it = TQObjectListIt(children); *it; ++it )
+ if ( !tqchildren.isEmpty() ) {
+ Q_ASSERT( count == tqchildren.count() );
+ for ( TQObjectListIt it = TQObjectListIt(tqchildren); *it; ++it )
fromStream( stream, *it );
}
else {
@@ -117,61 +117,61 @@ KWidgetStreamer::KWidgetStreamer ()
// TQCheckBox
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("checked") << TQString::fromLatin1("tristate");
- _map.insert(TQString::fromLatin1(TQCHECKBOX_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("checked") << TQString::tqfromLatin1("tristate");
+ _map.insert(TQString::tqfromLatin1(TQCHECKBOX_OBJECT_NAME_STRING), l);
// TQComboBox
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("editable") << TQString::fromLatin1("currentItem")
- << TQString::fromLatin1("maxCount") << TQString::fromLatin1("insertionPolicy")
- << TQString::fromLatin1("autoCompletion");
- _map.insert(TQString::fromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("editable") << TQString::tqfromLatin1("currentItem")
+ << TQString::tqfromLatin1("maxCount") << TQString::tqfromLatin1("insertionPolicy")
+ << TQString::tqfromLatin1("autoCompletion");
+ _map.insert(TQString::tqfromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), l);
// TQDial
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("tracking") << TQString::fromLatin1("wrapping")
- << TQString::fromLatin1("value");
- _map.insert(TQString::fromLatin1(TQDIAL_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("tracking") << TQString::tqfromLatin1("wrapping")
+ << TQString::tqfromLatin1("value");
+ _map.insert(TQString::tqfromLatin1(TQDIAL_OBJECT_NAME_STRING), l);
// TQLCDNumber
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("numDigits") << TQString::fromLatin1("mode")
- << TQString::fromLatin1("segmentStyle") << TQString::fromLatin1("value");
- _map.insert(TQString::fromLatin1(TQLCDNUMBER_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("numDigits") << TQString::tqfromLatin1("mode")
+ << TQString::tqfromLatin1("segmentStyle") << TQString::tqfromLatin1("value");
+ _map.insert(TQString::tqfromLatin1(TQLCDNUMBER_OBJECT_NAME_STRING), l);
// TQLineEdit
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("text") << TQString::fromLatin1("maxLength")
- << TQString::fromLatin1("echoMode") << TQString::fromLatin1("alignment");
- _map.insert(TQString::fromLatin1(TQLINEEDIT_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("text") << TQString::tqfromLatin1("maxLength")
+ << TQString::tqfromLatin1("echoMode") << TQString::tqfromLatin1("tqalignment");
+ _map.insert(TQString::tqfromLatin1(TQLINEEDIT_OBJECT_NAME_STRING), l);
// TQMultiLineEdit
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("text")
- << TQString::fromLatin1("alignment");
- _map.insert(TQString::fromLatin1(TQTEXTEDIT_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("text")
+ << TQString::tqfromLatin1("tqalignment");
+ _map.insert(TQString::tqfromLatin1(TQTEXTEDIT_OBJECT_NAME_STRING), l);
// TQRadioButton
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("checked");
- _map.insert(TQString::fromLatin1(TQRADIOBUTTON_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("checked");
+ _map.insert(TQString::tqfromLatin1(TQRADIOBUTTON_OBJECT_NAME_STRING), l);
// TQSlider
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("value");
- _map.insert(TQString::fromLatin1(TQSLIDER_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("value");
+ _map.insert(TQString::tqfromLatin1(TQSLIDER_OBJECT_NAME_STRING), l);
// TQSpinBox
l.clear();
- l << TQString::fromLatin1("enabled")
- << TQString::fromLatin1("value");
- _map.insert(TQString::fromLatin1(TQSPINBOX_OBJECT_NAME_STRING), l);
+ l << TQString::tqfromLatin1("enabled")
+ << TQString::tqfromLatin1("value");
+ _map.insert(TQString::tqfromLatin1(TQSPINBOX_OBJECT_NAME_STRING), l);
}